#
# spec file for package python-hgtools
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%bcond_without test

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-hgtools
Version:        6.5.2
Release:        19.1
Summary:        Mercurial support for setup tools
License:        GPL-2.0
Group:          Development/Languages/Python
Url:            https://github.com/jaraco/hgtools
Source:         https://files.pythonhosted.org/packages/source/h/hgtools/hgtools-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module setuptools_scm >= 1.15.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module pytest >= 2.8}
BuildRequires:  python2-backports.unittest_mock
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%python_subpackages

%description
hgtools builds on the setuptools_hg plugin for setuptools. hgtools
provides classes for inspecting and working with repositories in the
Mercurial version control system.

hgtools provides a plugin for setuptools that enables setuptools to find
files under the Mercurial version control system.


%prep
%setup -q -n hgtools-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with test}
%check
%python_exec setup.py test
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc CHANGES.rst README.rst LICENSE
%{python_sitelib}/*

%changelog
* Mon Jul 17 2017 toddrme2178@gmail.com
- Really implement single-spec version.
* Mon Jul 10 2017 toddrme2178@gmail.com
- Implement single-spec version
- Fix source and homepage URLs.
- Update to version 6.5
  * Issue #31: Add support for Git-backed Mercurial repositories with
    bookmarks on the tip.
- Update to version 6.4
  * Moved hosting to Github.
* Wed Apr 22 2015 tbechtold@suse.com
- update to 6.3:
  * Updated 'dev' revision to be compatible with setuptools 8 canonical
    pre-release version numbering (now '.dev0').
  * Pull Request #7: Fixed intermittent test failures.
  * Issue #28: Fixed poor parsing of git version. Also provide a nicer error
    message when no repo manager is found.
  * Added support for querying the Mercurial version in cmd.Mercurial.
  * Issue #21: GitManager is now only valid if Git 1.7.10 or later is present.
- Add python-pytest as BuildRequires for testing
* Mon Sep 15 2014 ro@suse.de
- add LICENSE to documentation
* Mon Sep 15 2014 tbechtold@suse.com
- update to version 6.0
  * Issue #23: hgtools no longer imports Mercurial and thus does not link to
    it. Applications that wish to use the in-process Mercurial manager must
    first `import mercurial.dispatch` in their application.
  * Issue #23: hgtools is now licensed under the MIT license.
  * Issue #19: Add file finder support for git. Credit to Berry Phillips.
  * Issue #20: Added support for listing all git tags. Credit to Berry Phillips.
  * In version inference, always fallback to increment (or None) when an
    Exception occurs in the calculation.
  * Issue #17: Fix regression on older versions of setuptools where unspecified
    distribution attributes would cause use_vcs_version of None to supersede
    a supplied use_hg_version.
  * Added new ``use_vcs_version`` distutils parameter to supersede
    ``use_hg_version``. Clients should update to use this new parameter as soon
    as hgtools 5.0 is generally available.
  * Initial git support. The tool now nominally supports eliciting the project
    version from a git tag. Many of the hg features are not yet implemented,
    such as auto-incrementing versions when the current revision is not on a
    tag and file discovery from repo metadata.
    This new Git support provides experimental support for dual-hosted
    repositories (such as those found on Kiln). Since file discovery is not yet
    tested or implemented, there are likely to be yet undiscovered issues.
  * Refactored the Manager models to better support the two repositories.
    Clients that use hgtools to programmatically manipulate repositories will
    need to update to use the new names. In particular, HGRepoManager was
    renamed to RepoManager. SubprocessManager renamed to MercurialManager and
    a new GitManager was created. The LibraryManager was renamed to
    MercurialInProcManager.
* Mon Dec  9 2013 p.drouand@gmail.com
- Update to version 4.0
  + No changelog available
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Jan 30 2013 saschpe@suse.de
- Use license from setup.py
- There's no docs to build
* Wed Jan 23 2013 adrian@suse.de
- initial package of version 2.0.2
